/*

    ThermostatQA - test framework for Thermostat Monitoring Tool

    Copyright 2013 Red Hat, Inc.

This file is part of ThermostatQA

ThermostatQA is distributed under the GNU General Public License,
version 2 or any later version (with a special exception described
below, commonly known as the "Classpath Exception").

A copy of GNU General Public License (GPL) is included in this
distribution, in the file COPYING.

Linking ThermostatQA code with other modules is making a combined work
based on ThermostatQA.  Thus, the terms and conditions of the GPL
cover the whole combination.

As a special exception, the copyright holders of ThermostatQA give you
permission to link this code with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on ThermostatQA code.  If you modify ThermostatQA, you may
extend this exception to your version of the software, but you are
not obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.thermostat.qa.testsuites;

import java.io.IOException;
import java.util.List;


import org.thermostat.qa.framework.Assert;
import org.thermostat.qa.framework.ThermostatTest;

/**
 * Class DBSchemeSmokeTest
 * contains basic smoke tests for checking the db scheme for thermostat mongodb
 * storage. The test starts storage and one agent. Then all the collections
 * that should not be empty after these steps are checked - there should be
 * a non-null record in each (findOne() in the js script for mongo shell), and
 * its elements should be of the right types.
 *
 */
public class DBSchemeSmokeTest extends ThermostatTest
{
    
    private List<String> scriptOutput;
    
    @Override
    protected void tearDown()
    {

    }

    @Override
    protected void setUp()
    {
        // TODO
        //start storage
        startStorage();
        //start agent
        new AgentThread().start();

        //run js test script, get output
        try
        {
            scriptOutput = runHelperBashScript("check-collections-smoke.sh");
        }
        catch (IOException e)
        {
            e.printStackTrace();
        }
        
        //stop the agent and storage
        try
        {
            runHelperBashScript("stop_all_therm_agents.sh");
            stopStorage();
        }
        catch (IOException e)
        {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
    }

    public void testAgentConfig(){
        Assert.assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        //find a line in scriptOutput containing "schema for agent-config is OK"
        checkPresenceOfPatternInTexts(scriptOutput, "schema for agent-config is OK");
    }
    public void testBackendInfo(){
        Assert.assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        checkPresenceOfPatternInTexts(scriptOutput, "schema for backend-info is OK");
    }
    public void testCpuStats(){
        Assert.assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        checkPresenceOfPatternInTexts(scriptOutput, "schema for cpu-stats is OK");
    }
    public void testHostInfo(){
        Assert.assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        checkPresenceOfPatternInTexts(scriptOutput, "schema for host-info is OK");
    }
    public void testMemoryStats(){
        Assert.assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        checkPresenceOfPatternInTexts(scriptOutput, "schema for memory-stats is OK");
    }
    /* this test fails on fedora 20 (ipv6 address is null is it ok or not? on rhel6 it passes)
    public void testNetworkInfo(){
        Assert.assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        checkPresenceOfPatternInTexts(scriptOutput, "schema for network-info is OK");
    }*/
    public void testNumaHostInfo(){
        Assert.assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        checkPresenceOfPatternInTexts(scriptOutput, "schema for numa-host-info is OK");
    }
    public void testNumaStat(){
        Assert.assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        checkPresenceOfPatternInTexts(scriptOutput, "schema for numa-stat is OK");
    }
    /* system.indexes created by mongo, nothing for us to check
     * public void testSystemIndexes(){
        Assert.assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        checkPresenceOfPatternInTexts(scriptOutput, "schema for system.indexes is OK");
    }*/

    public void testVmClassStats(){
        Assert.assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        checkPresenceOfPatternInTexts(scriptOutput, "schema for vm-class-stats is OK");
    }
    public void testVmCpuStats(){
        Assert.assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        checkPresenceOfPatternInTexts(scriptOutput, "schema for vm-cpu-stats is OK");
    }
    /*public void testVmDeadlockData(){
        Assert.assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        checkPresenceOfPatternInTexts(scriptOutput, "schema for vm-deadlock-data is UNKNOWN");
    }*/
    public void testVmGcStats(){
        Assert.assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        checkPresenceOfPatternInTexts(scriptOutput, "schema for vm-gc-stats is OK");
    }
    /*public void testVmHeapInfo(){
        Assert.assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        checkPresenceOfPatternInTexts(scriptOutput, "schema for heap-info is UNKNOWN");
    }*/
    public void testVmInfo(){
        Assert.assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        checkPresenceOfPatternInTexts(scriptOutput, "schema for vm-info is OK");
    }
    /*public void testVmJmxNotification(){
        Assert.assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        checkPresenceOfPatternInTexts(scriptOutput, "schema for vm-jmx-notification is UNKNOWN");
    }
    public void testVmJmxNotificationStatus(){
        Assert.assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        checkPresenceOfPatternInTexts(scriptOutput, "schema for vm-jmx-notification-status is UNKNOWN");
    }*/
    public void testVmMemoryStats(){
        Assert.assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        checkPresenceOfPatternInTexts(scriptOutput, "schema for vm-memory-stats is OK");
    }
    public void testVmThreadCapabilities(){
        Assert.assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        checkPresenceOfPatternInTexts(scriptOutput, "schema for vm-thread-capabilities is OK");
    }
    public void testVmThreadHarvesting(){
        Assert.assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        checkPresenceOfPatternInTexts(scriptOutput, "schema for vm-thread-harvesting is OK");
    }
    /*public void testVmThreadInfo(){
        Assert.assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        checkPresenceOfPatternInTexts(scriptOutput, "schema for vm-thread-info is UNKNOWN");
    }
    public void testVmThreadSummary(){
        Assert.assertNotNull(scriptOutput, "problems running auxiliary js script in mongo shell");
        checkPresenceOfPatternInTexts(scriptOutput, "schema for vm-thread-summary is UNKNOWN");
    }*/

    
    public static void main(String[] args) {
        new DBSchemeSmokeTest().doTests(args);
    }

}
